@@ -1,6 +1,6 @@
 /*
  * This file is part of the KDE Akonadi Search Project
- * SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  *
@@ -24,7 +24,7 @@ class NoteSearchStore : public PIMSearchStore
 public:
     explicit NoteSearchStore(QObject *parent = nullptr);
 
-    QStringList types() override;
+    Q_REQUIRED_RESULT QStringList types() override;
 };
 }
 }
